/*
 * Zorin App Grid: Show the App Grid button in the panel.
 *
 * Copyright (C) 2019 Zorin OS Technologies Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

const Main = imports.ui.main;

const Me = imports.misc.extensionUtils.getCurrentExtension();
const AppGridButton = Me.imports.appGridButton;
const ActivitiesButton = Me.imports.activitiesButton;

let appGridButton;
let activitiesButton;
let oldDash;

function init() {
}

function enable() {
    // Remove Activities Button from panel
    let oldActivitiesButton = Main.panel.statusArea['activities'];
    let activitiesVisible = oldActivitiesButton.actor.visible;
    oldActivitiesButton.destroy();

    activitiesButton = new ActivitiesButton.ActivitiesButton();
    Main.panel.addToStatusArea('activities', activitiesButton, 0, 'left');
    if (!activitiesVisible) {
        activitiesButton.actor.hide();
    }

    appGridButton = new AppGridButton.AppGridButton(Main.panel.actor);
    Main.panel._leftBox.insert_child_at_index(appGridButton, 0);

    // Pretend I'm the dash: meant to make appgrid swarm animation come from the
    // appGridButton.
    oldDash = Main.overview._dash;
    Main.overview._dash = appGridButton;
}

function disable() {
    Main.overview._dash = oldDash;
    oldDash = null;

    Main.panel._leftBox.remove_child(appGridButton);
    appGridButton.destroy();
    appGridButton = null;

    let activitiesVisible = activitiesButton.actor.visible;
    Main.panel._leftBox.remove_child(activitiesButton.container);
    activitiesButton.destroy();
    activitiesButton = null;

    // Add Activities Button back to panel
    let newActivitiesButton = Main.panel._ensureIndicator('activities');
    if (newActivitiesButton != null) {
        Main.panel._addToPanelBox('activities', newActivitiesButton, 0, Main.panel._leftBox);
        if (!activitiesVisible) {
            newActivitiesButton.actor.hide();
        }
    };
}
